// KreateCD - CD recording software for the K desktop environment
//
// 2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
//
// This file is subject to the terms and conditions of the GNU General
// Public License.  See the file COPYING in the main directory of the
// KreateCD distribution for more details.

#ifndef TOCCDDA2WAV_INCLUDED
#define TOCCDDA2WAV_INCLUDED

#include "TOCReader.h"

class TOCCdda2wav : public TOCReader {
 protected:
  virtual int invokeTOCReader(bool readBurner);
  virtual bool processStderrLine(char *buffer);
  virtual int  processCleanup(int rval); 
};


#endif

